yakumo.neutron.v2.lb

Package yakumo :: Package neutron :: Package v2 :: Package lb |
[hide private]
[frames] | no frames]

# Source Code for Package yakumo.neutron.v2.lb

     1  from . import health_monitor
     2  from . import pool
     3
     4
     5 -class Client(object):
     6
     7 -    def __init__(self, client, **kwargs):
     8          self.health_monitor = health_monitor.Manager(client, **kwargs)
     9          self.pool = pool.Manager(client, **kwargs)
    10